@@ -26,8 +26,11 @@ sub configure_parser {
         no_ignore_case
     );
     Getopt::Long::Configure( @standard, @opts );
+
+    return;
 }
 
+
 sub _generate_ignore_dir {
     my ( $option_name, $opt ) = @_;
 
@@ -895,6 +898,9 @@ sub mutex_options {
             g => 1,
             l => 1,
         },
+        I => {
+            f => 1,
+        },
         L => {
             A => 1,
             B => 1,
@@ -959,6 +965,7 @@ sub mutex_options {
             B => 1,
             C => 1,
             H => 1,
+            I => 1,
             L => 1,
             break => 1,
             c => 1,
@@ -969,6 +976,7 @@ sub mutex_options {
             group => 1,
             h => 1,
             heading => 1,
+            i => 1,
             l => 1,
             m => 1,
             match => 1,
@@ -976,6 +984,7 @@ sub mutex_options {
             output => 1,
             p => 1,
             passthru => 1,
+            'smart-case' => 1,
             u => 1,
             v => 1,
             x => 1,
@@ -1030,6 +1039,9 @@ sub mutex_options {
             g => 1,
             l => 1,
         },
+        i => {
+            f => 1,
+        },
         l => {
             A => 1,
             B => 1,
@@ -1139,6 +1151,9 @@ sub mutex_options {
             o => 1,
             output => 1,
         },
+        'smart-case' => {
+            f => 1,
+        },
         u => {
             f => 1,
             g => 1,
